MandalaNetworkView | unified-mandala - v1.0.0
Description: Documentation for unified-mandala

# Function MandalaNetworkView

- MandalaNetworkView(props, deprecatedLegacyContext?): ReactNode

- #### Parameters

  - props: {}
  - `Optional` deprecatedLegacyContext: any

    #### Deprecated

    #### See

    React Docs

  #### Returns ReactNode

  - Defined in packages/unifiedmandala-ui/components/MandalaNetworkView.tsx:25

#####
Index

### Properties

contextTypes?
defaultProps?
displayName?
propTypes?

## Properties

### `Optional` contextTypes

contextTypes?: ValidationMap<any>

#### Deprecated

Lets you specify which legacy context is consumed by this component.

#### See

Legacy React Docs

- Defined in node_modules/.pnpm/@types+react@18.3.23/node_modules/@types/react/index.d.ts:1156

### `Optional` defaultProps

defaultProps?: Partial<{}>

Used to define default values for the props accepted by the component.

#### Type declaration

#### See

React Docs

#### Example

    type Props = { name?: string }

    const MyComponent: FC<Props> = (props) => {
      return <div>{props.name}</div>
    }

    MyComponent.defaultProps = {
      name: 'John Doe'
    }

#### Deprecated

Use values for destructuring assignments instead.

- Defined in node_modules/.pnpm/@types+react@18.3.23/node_modules/@types/react/index.d.ts:1179

### `Optional` displayName

displayName?: string

Used in debugging messages. You might want to set it explicitly if you want to display a different name for debugging purposes.

#### See

Legacy React Docs

#### Example

    const MyComponent: FC = () => {
      return <div>Hello!</div>
    }

    MyComponent.displayName = 'MyAwesomeComponent'

- Defined in node_modules/.pnpm/@types+react@18.3.23/node_modules/@types/react/index.d.ts:1198

### `Optional` propTypes

propTypes?: WeakValidationMap<{}>

Used to declare the types of the props accepted by the component. These types will be checked during rendering and in development only.

We recommend using TypeScript instead of checking prop types at runtime.

#### Type declaration

#### See

React Docs

- Defined in node_modules/.pnpm/@types+react@18.3.23/node_modules/@types/react/index.d.ts:1147